/*
 * csv-io.h: interfaces to save/read Sheets using a CSV encoding.
 * (most of the code taken from xml-io.h by Daniel Veillard <Daniel.Veillard@w3.org>)
 *
 * Vincent Renardias <vincent@ldsol.com>
 *
 * $Id: csv-io.h,v 1.5 1999/12/30 09:11:55 unammx Exp $
 */

#ifndef GNUMERIC_CSV_IO_H
#define GNUMERIC_CSV_IO_H

#include "sheet.h"
#include "plugin.h"

PluginInitResult       init_plugin (CommandContext *context, PluginData *pd);

#endif /* GNUMERIC_CSV_IO_H */
